==> clean900_1.1.2-8.tar.gz: clean900-1.1.2/usr/bin/clean900/clean900-fr.sh <==
#!/bin/sh
#Clean900
#version 1.1.2
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

source /usr/bin/clean900/funclean-fr.sh

gest=`ps ux |grep -c hildon-application-manager`

if [ $gest = 3 ]
	then
		quest=$(gestoreaperto;echo $?)

	else
		quest=0
fi

if [ $quest -eq 0 ]
	then
		killappman
		inputline=$(primostep --separator=":")
		IFS=":"
		for prova in $inputline; do
		case $prova in

			"clean")clean;;

			"autoclean")autoclean;;

			"autoremove")autoremove;;

			"purge")purge;;

			"Update")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
				if [ "$conn" != "1" ]
					then
						ric=`ricconn;echo $?`
						if [ "$ric" = 0 ]
							then
								connessione
								update
							else
								popup_ann
						fi
					else
						update
				fi;;

			"Upgrade")
				res=$(echo "n" | apt-get upgrade )
				if [ $? -eq 1 ]; then
					if zenity --title=Clean900 --question --text "$res"; then
						res=$(apt-get upgrade -f -y --force-yes)
						aggiornamenti
						else
							noaggiornamenti
					fi
				fi
					zenity --title=Clean900 --info --text "$res";;

				"Applications") 
						choice=$(applicazioni --separator=":");
						case $choice in
	
				"Créer une sauvegarde de vos applications")
					mkdir /home/user/MyDocs/clean900/ > \/tmp\/output.txt 2> \/dev\/null
					ricback=`zenity --warning --title CleaN900 --text "Etes-vous sûr que vous voulez créer un file de sauvegarde? Si vous voulez le créer, cliquez sur OK, sinon pas dans le vide";echo $?`
					if [ "$ricback" -eq 0 ]
						then
						nomefile=`zenity --entry --text="Entrez le nom de la sauvegarde" --entry-text="es. backup_01-01-11"` && \
							dpkg --get-selections > /home/user/MyDocs/clean900/$nomefile.txt
							backupcreato
						else
							popup_ann
					fi;;

				"Restauration à partir d'applications de sauvegarde")
						conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
							if [ "$conn" != "1" ]
								then
									ric=`ricconn;echo $?`
										if [ "$ric" = 0 ]
											then
												connessione
						ricrip=`zenity --warning --title CleaN900 --text "Etes-vous sûr que vous souhaitez restaurer un file de sauvegarde? Si vous souhaitez restaurer cliquez sur OK, sinon pas dans le vide";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
								backup=`selbackup` && dpkg --set-selections < $backup
								opincorso
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											ripristino
										else
											popup_ann
										fi
									fi
										zenity --title=Clean900 --info --text "$res"
							else
								popup_ann
						fi
											else
												popup_ann
										fi
							fi;;

				"Installez un paquet")
					pacchetto=`seldeb`
					if [ $? -eq 0 ]; then
						dpkg -i $pacchetto | zenity --progress --pulsate --title="Installation" --text="Attendez que la barre charge"
						paccinst
						else
							popup_ann
					fi;;				

				"Remove paquet spécifiques")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
						if [ "$conn" != "1" ]
							then
								ric=`ricconn;echo $?`
									if [ "$ric" = 0 ]
										then
											connessione
											pacchetto=`rempac`
											dpkg -r $pacchetto | waitdis
											paccdis
										else
											popup_ann
									fi
							else
								pacchetto=`zenity --entry --title='Supprimer' --text='Entrez le nom du paquet'`
									if [ $? -eq 0 ]; then
										dpkg -r $pacchetto | waitdis
										paccdis
										else
											popup_ann
									fi
						fi;;

				"Reboot")riavvio;;
			esac
			;;

		"Reboot")riavvio;;

esac
done
	else
		popup_ann
fi

==> clean900_1.1.2-9.tar.gz: clean900-1.1.2/usr/bin/clean900/clean900-fr.sh <==
#!/bin/sh
#Clean900
#version 1.1.2
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

source /usr/bin/clean900/funclean-fr.sh

gest=`ps ux |grep -c hildon-application-manager`

if [ $gest = 3 ]
	then
		quest=$(gestoreaperto;echo $?)

	else
		quest=0
fi

if [ $quest -eq 0 ]
	then
		killappman
		inputline=$(primostep --separator=":")
		IFS=":"
		for prova in $inputline; do
		case $prova in

			"clean")clean;;

			"autoclean")autoclean;;

			"autoremove")autoremove;;

			"purge")purge;;

			"Update")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
				if [ "$conn" -ne "0" ]
					then
						ric=`ricconn;echo $?`
						if [ "$ric" = 0 ]
							then
								connessione
								update
							else
								popup_ann
						fi
					else
						update
				fi;;

			"Upgrade")
				res=$(echo "n" | apt-get upgrade )
				if [ $? -eq 1 ]; then
					if zenity --title=Clean900 --question --text "$res"; then
						res=$(apt-get upgrade -f -y --force-yes)
						aggiornamenti
						else
							noaggiornamenti
					fi
				fi
					zenity --title=Clean900 --info --text "$res";;

				"Applications") 
						choice=$(applicazioni --separator=":");
						case $choice in
	
				"Créer une sauvegarde de vos applications")
					mkdir /home/user/MyDocs/clean900/ > \/tmp\/output.txt 2> \/dev\/null
					ricback=`zenity --warning --title CleaN900 --text "Etes-vous sûr que vous voulez créer un file de sauvegarde? Si vous voulez le créer, cliquez sur OK, sinon pas dans le vide";echo $?`
					if [ "$ricback" -eq 0 ]
						then
						nomefile=`zenity --entry --text="Entrez le nom de la sauvegarde" --entry-text="es. backup_01-01-11"` && \
							dpkg --get-selections > /home/user/MyDocs/clean900/$nomefile.txt
							backupcreato
						else
							popup_ann
					fi;;

				"Restauration à partir d'applications de sauvegarde")
						conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
							if [ "$conn" -ne "0" ]
								then
									ric=`ricconn;echo $?`
										if [ "$ric" = 0 ]
											then
												connessione
						ricrip=`zenity --warning --title CleaN900 --text "Etes-vous sûr que vous souhaitez restaurer un file de sauvegarde? Si vous souhaitez restaurer cliquez sur OK, sinon pas dans le vide";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
								backup=`selbackup` && dpkg --set-selections < $backup
								opincorso
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											ripristino
										else
											popup_ann
										fi
									fi
										zenity --title=Clean900 --info --text "$res"
							else
								popup_ann
						fi
											else
												popup_ann
										fi
							fi;;

				"Installez un paquet")
					pacchetto=`seldeb`
					if [ $? -eq 0 ]; then
						dpkg -i $pacchetto | zenity --progress --pulsate --title="Installation" --text="Attendez que la barre charge"
						paccinst
						else
							popup_ann
					fi;;				

				"Remove paquet spécifiques")conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`
						if [ "$conn" -ne "0" ]
							then
								ric=`ricconn;echo $?`
									if [ "$ric" = 0 ]
										then
											connessione
											pacchetto=`rempac`
											dpkg -r $pacchetto | waitdis
											paccdis
										else
											popup_ann
									fi
							else
								pacchetto=`zenity --entry --title='Supprimer' --text='Entrez le nom du paquet'`
									if [ $? -eq 0 ]; then
										dpkg -r $pacchetto | waitdis
										paccdis
										else
											popup_ann
									fi
						fi;;

				"Reboot")riavvio;;
			esac
			;;

		"Reboot")riavvio;;

esac
done
	else
		popup_ann
fi
